@@ -321,11 +321,10 @@ def image_preview(
             if not img_bytes:
                 from .. import qs_error_string
 
-                qs_default_console.print(
+                return qs_default_console.print(
                     qs_error_string,
                     "Failed to download image" if user_lang != "zh" else "图片下载失败",
                 )
-                return
 
             img = requirePackage("PIL", "Image", "Pillow").open(
                 requirePackage("io", "BytesIO")(img_bytes)
@@ -392,14 +391,14 @@ def image_preview(
         qs_default_status.stop()
 
         qs_default_console.print(
-            " " * int(max((console_width - _real_width) // 2, 0)),
+            " " * math.ceil((console_width - _real_width) / 2),
             end="",
         )
 
         imgcat(
             buf,
             width=min(_real_width, console_width),
-            height=_real_height,
+            height=min(_real_height, console_height),
             force_show=force_show_option,
         )
 
